MethodChannelManagedConfigurations class

An implementation of ManagedConfigurationsPlatform that uses method channels.

Inheritance

Properties

getManagedConfigurations Future<Map<String, dynamic>?>
Returns managed app configurations as Json
no setteroverride
hashCode int
The hash code for this object.
no setterinherited
mangedConfigurationsStream Stream<Map<String, dynamic>?>
Returns a broadcast stream which calls on managed app configuration changes Json will be returned Call dispose when stream is not more necessary
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

dispose() → void
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
reportKeyedAppStates(String key, Severity severity, String? message, String? data) Future<void>
This method is only supported on Android Platform
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited