mangedConfigurationsStream property

  1. @override
Stream<Map<String, dynamic>?> get mangedConfigurationsStream
override

Returns a broadcast stream which calls on managed app configuration changes Json will be returned Call dispose when stream is not more necessary

Implementation

@override
Stream<Map<String, dynamic>?> get mangedConfigurationsStream {
  _actionApplicationRestrictionsChangedSubscription ??=
      _managedConfigurationEventChannel
          .receiveBroadcastStream()
          .listen((newManagedConfigurations) {
    if (newManagedConfigurations != null) {
      try {
        _mangedConfigurationsController
            .add(json.decode(newManagedConfigurations));
      } on FormatException catch (e) {
        _mangedConfigurationsController.addError(e);
      }
    }
  });
  return _managedConfigurationsStream;
}