ManagedConfigurationsPlatform class abstract

Inheritance
  • Object
  • PlatformInterface
  • ManagedConfigurationsPlatform
Implementers

Constructors

ManagedConfigurationsPlatform()
Constructs a ManagedConfigurationsPlatform.

Properties

getManagedConfigurations → Future<Map<String, dynamic>?>
no setter
hashCode → int
The hash code for this object.
no setterinherited
mangedConfigurationsStream → Stream<Map<String, dynamic>?>
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

dispose() → void
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
reportKeyedAppStates(String key, Severity severity, String? message, String? data) → Future<void>
This method is only supported on Android Platform
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

instance ↔ ManagedConfigurationsPlatform
The default instance of ManagedConfigurationsPlatform to use.
getter/setter pair